
function [UserVar,CtrlVar,MeshBoundaryCoordinates]=DefineInitialInputs(UserVar,CtrlVar)


%% Select the type of run by uncommenting one of the following options:
UserVar.OutputExpName='jutul_slope_lgm_MRI-CGCM3_fc10';

if isempty(UserVar) || ~isfield(UserVar,'RunType')    
   UserVar.RunType='Forward-Transient';
end

UserVar.IOFilesPath = '';

% Domain
CtrlVar.ReadInitialMesh=1;           % default 1
UserVar.MeshOutlinePath = [UserVar.IOFilesPath,'/MeshFiles/mesh_lines/footprint_jutul_slope.dat'];
CtrlVar.ReadInitialMeshFileName=[UserVar.IOFilesPath,'/MeshFiles/mesh_jutul_slope_ref_initial_dbde.mat'];
CtrlVar.Parallel.uvhAssembly.spmd.isOn=1; %for parallel runs

% Boundaries
UserVar.GeometryInterpolant=[UserVar.IOFilesPath,'/Interpolants/Jutulstraumen/slope_extent/BedMachine210914_GeometryInterpolant_jutul_slope.mat'];
UserVar.SurfaceVelocityInterpolant=[UserVar.IOFilesPath,'/Interpolants/Jutulstraumen/slope_extent/Measures_SurfVelInterpolant_jutul_slope.mat'];

UserVar.CFile=[UserVar.IOFilesPath,'/InputAC/FC10_bma_jutul_dhdte10.mat']; 
UserVar.AFile=[UserVar.IOFilesPath,'/InputAC/FA_bma_jutul_dhdte10.mat'];
CtrlVar.SlidingLaw='Weertman'; %{'Weertman'|'Umbi'|'Cornford'} default: Weertman


% Forcings
UserVar.SMB.File=[UserVar.IOFilesPath,'/Interpolants/Jutulstraumen/slope_extent/racmo_smb_jutul_slope.mat'];

UserVar.SMB.Tclim_file=[UserVar.IOFilesPath,'/Interpolants/ant_wide/lgm/FTc_MRI-CGCM3.mat'];
UserVar.SMB.Pclim_file=[UserVar.IOFilesPath,'/Interpolants/ant_wide/lgm/FPc_MRI-CGCM3.mat'];
UserVar.SMB.s_ref_file=[UserVar.IOFilesPath,'/Interpolants/ant_wide/lgm/Fsr_MRI-CGCM3.mat'];


if ~isfile(UserVar.GeometryInterpolant) || ~isfile(UserVar.SurfaceVelocityInterpolant)     
     fprintf('\n This run requires the additional input files: \n %s \n %s  \n \n',UserVar.GeometryInterpolant,UserVar.SurfaceVelocityInterpolant)          
end

run ../load_common_run_parameters;
CtrlVar.doplots=0;

%% Duration

CtrlVar.dt=0.01;
CtrlVar.time=0;
CtrlVar.TotalTime=30000;
CtrlVar.TotalNumberOfForwardRunSteps=10e12;

CtrlVar.DefineOutputsDt = 100;       % every years

%% Run-type specific
CtrlVar.Experiment=UserVar.RunType;

        
CtrlVar.InverseRun=0;
CtrlVar.TimeDependentRun = 1;
CtrlVar.Restart          = 0;
CtrlVar.ResetTime        = 0;

UserVar.SeaLevelStart     = 0; % PD sea level
UserVar.SeaLevelEnd       = -134; % LGM sea level (Lambeck et al., 2014; PNAS)
UserVar.SeaLevelStartTime = 0;   % year
UserVar.SeaLevelEndTime   = 3000; % year       

UserVar.applyDeltaBedrock = 1;
UserVar.deltaBedrockInit  = 3000;
UserVar.deltaBedrockEnd   = 4000;
UserVar.deltaBedrockFile=[UserVar.IOFilesPath,'/Interpolants/ant_wide/ICE-6G_dzl_lgm.mat'];
CtrlVar.GeometricalVarsDefinedEachTransienRunStepByDefineGeometry="SB";        

CtrlVar.ATSdtMax=1.0;

CtrlVar.InfoLevelNonLinIt=1;
UserVar.Slipperiness.ReadFromFile=1; % default 1 (if no CFile provided, reads C-Estimate.mat)
UserVar.AGlen.ReadFromFile=1;        % default 0? (if no AFile provided, reads AGlen-Estimate.mat)
UserVar.Temp.ReadFromFile=0;

CtrlVar.ReadInitialMesh=1;           
CtrlVar.AdaptMeshInitial=1;
CtrlVar.AdaptMesh=1;                 
CtrlVar.AdaptMeshRunStepInterval=0; CtrlVar.AdaptMeshTimeInterval=20;
CtrlVar.AdaptMeshMaxIterations=5;

UserVar.SMB.ReadFromFile=1;

UserVar.SMB.TimeInit=4000;
UserVar.SMB.TimeEnd=5000;
UserVar.SMB.ComputeFromTS=1;

CtrlVar.MassBalanceGeometryFeedback=3;
UserVar.Qbm.Mode='None'; % '{'ReadFromFile'|'Quadratic'|'PICO'}

if CtrlVar.Restart==1
    CtrlVar.NameOfRestartFiletoRead=[UserVar.IOFilesPath,'/outputs/Restart-jutul_slope_lgm_MRI-CGCM3_fc10-Forward-Transient-3000000'];
    CtrlVar.ReadInitialMesh=0;
    CtrlVar.AdaptMesh=1;
    CtrlVar.AdaptMeshInitial=0;
    CtrlVar.AdaptMeshTimeInterval=50;  
end

fname_restart=sprintf('%s/outputs/Restart-%s-%s-%07i',UserVar.IOFilesPath,UserVar.OutputExpName,UserVar.RunType,round(100*CtrlVar.TotalTime));
CtrlVar.NameOfRestartFiletoWrite=fname_restart;

MeshBoundaryCoordinates=CreateMeshBoundaryCoordinates(CtrlVar,UserVar.MeshOutlinePath);
%%
UserVar.AddDataErrors=0;

%%
filename=sprintf('IR-%s-%s-Nod%i-%s-%s-Cga%f-Cgs%f-Aga%f-Ags%f-%i-%i-%s',...
    UserVar.RunType,...
    CtrlVar.Inverse.MinimisationMethod,...
    CtrlVar.TriNodes,...
    CtrlVar.Inverse.AdjointGradientPreMultiplier,...
    CtrlVar.Inverse.DataMisfit.GradientCalculation,...
    CtrlVar.Inverse.Regularize.logC.ga,...
    CtrlVar.Inverse.Regularize.logC.gs,...
    CtrlVar.Inverse.Regularize.logAGlen.ga,...
    CtrlVar.Inverse.Regularize.logAGlen.gs,...
    CtrlVar.CisElementBased,...
    CtrlVar.AGlenisElementBased,...
    CtrlVar.Inverse.InvertFor);
filename=replace(filename,'.','k');
CtrlVar.Inverse.NameOfRestartOutputFile=filename;
CtrlVar.Inverse.NameOfRestartInputFile=CtrlVar.Inverse.NameOfRestartOutputFile;

end
